@@ -30,6 +30,7 @@ class SlashCommandRequest:
         Sends a slash command put request to the Discord API
 
         ``slash_commands`` must contain all the commands
+
         :param slash_commands: List of all the slash commands to make a put request to discord with.
         :param guild_id: ID of the guild to set the commands on. Pass `None` for the global scope.
         """
@@ -39,7 +40,7 @@ class SlashCommandRequest:
         """
         Sends a slash command delete request to Discord API.
 
-        :param guild_id: ID of the guild to add command. Pass `None` to add global command.
+        :param guild_id: ID of the guild to remove command. Pass `None` to remove global command.
         :param cmd_id: ID of the command.
         :return: Response code of the request.
         """
@@ -49,7 +50,7 @@ class SlashCommandRequest:
         """
         Sends a slash command get request to Discord API for all commands.
 
-        :param guild_id: ID of the guild to add command. Pass `None` to add global command.
+        :param guild_id: ID of the guild to get commands. Pass `None` to get global commands.
         :return: JSON Response of the request.
         """
         return self.command_request(method="GET", guild_id=guild_id)
@@ -79,7 +80,7 @@ class SlashCommandRequest:
         Sends a slash command add request to Discord API.
 
         :param guild_id: ID of the guild to add command. Pass `None` to add global command.
-        :param cmd_name: Name of the command. Must be 3 or longer and 32 or shorter.
+        :param cmd_name: Name of the command. Must be match the regular expression ``^[a-z0-9_-]{1,32}$``.
         :param description: Description of the command.
         :param options: List of the function.
         :return: JSON Response of the request.
